@@ -13,85 +13,72 @@
 
 namespace Views {
 
-  class DatesEntry : public Lum::Model::ListTable::Entry
+  class DatesEntryDataProvider : public DatesEntryModel::DataProvider
   {
   public:
-    ::Data::DatePtr     date;
-    Lum::Base::Calendar startDate;
-    Lum::Base::Calendar endDate;
-
-  public:
-    DatesEntry(Lum::Model::ListTable* table,
-               ::Data::DatePtr date,
-               const Lum::Base::Calendar& startDate,
-               const Lum::Base::Calendar& endDate)
-    : Lum::Model::ListTable::Entry(table),date(date),startDate(startDate),endDate(endDate)
-    {
-      // no code
-    }
-
-    std::wstring DateToString(const Lum::Base::Calendar& date) const
-    {
-      return Lum::Base::NumberToWString(date.GetDayOfMonth())+L"."+
-      Lum::Base::NumberToWString(date.GetMonth())+L"."+
-      Lum::Base::NumberToWString(date.GetYear());
-    }
-
-    std::wstring GetString(size_t column) const
+    std::wstring GetString(const DatesEntryModel::Iterator& iter, size_t column) const
     {
       switch (column) {
       case 1:
         {
           std::wstring res;
 
-          res=startDate.GetLocaleDate();
+          res=(*iter)->startDate.GetLocaleDate();
 
-          if (!date->wholeDay) {
-            res+=L" "+date->startTime.GetLocaleTime();
+          if (!(*iter)->date->wholeDay) {
+            res+=L" "+(*iter)->date->startTime.GetLocaleTime();
           }
 
-          if (startDate!=endDate) {
-            res+=L"-"+endDate.GetLocaleDate();
+          if ((*iter)->startDate!=(*iter)->endDate) {
+            res+=L"-"+(*iter)->endDate.GetLocaleDate();
 
-            if (!date->wholeDay) {
-              res+=L" "+date->endTime.GetLocaleTime();
+            if (!(*iter)->date->wholeDay) {
+              res+=L" "+(*iter)->date->endTime.GetLocaleTime();
             }
           }
-          else if (!date->wholeDay) {
-            res+=L"-"+date->endTime.GetLocaleTime();
+          else if (!(*iter)->date->wholeDay) {
+            res+=L"-"+(*iter)->date->endTime.GetLocaleTime();
           }
 
           return res;
         }
       case 2:
-        return date->GetAttribute(::Data::Date::DateType::description);
+        return (*iter)->date->GetAttribute(::Data::Date::DateType::description);
       default:
         return L"";
       }
     }
+  };
 
-    bool IsGreater(const Lum::Model::ListTable::Entry* other, size_t column) const
+  class DatesEntryComparator : public DatesEntryModel::Comparator
+  {
+  public:
+    bool operator()(const DatesEntryModel::ElementType& a,
+                    const DatesEntryModel::ElementType& b,
+                    size_t column, bool down) const
     {
-      const DatesEntry *tmp=dynamic_cast<const DatesEntry*>(other);
-
-      if (startDate>tmp->startDate) {
+      if (a->startDate<b->startDate) {
         return true;
       }
-      else if (startDate==tmp->startDate) {
-        if (date->wholeDay && tmp->date->wholeDay) {
+      else if (a->startDate==b->startDate) {
+        if (a->date->wholeDay && b->date->wholeDay) {
           return false;
         }
-        else if (date->wholeDay && !tmp->date->wholeDay) {
-          // tmp cannot be smaller
-          return false;
-        }
-        else if (!date->wholeDay && tmp->date->wholeDay) {
+        else if (a->date->wholeDay && !b->date->wholeDay) {
           // Current date must be bigger, if it does not also point to 0:00:00
-          return !(date->startTime.GetHour()==0 && date->startTime.GetMinute()==0 && date->startTime.GetSecond()==0);
+          return !(a->date->startTime.GetHour()==0 &&
+                   a->date->startTime.GetMinute()==0 &&
+                   a->date->startTime.GetSecond()==0);
+        }
+        else if (!a->date->wholeDay && b->date->wholeDay) {
+          // b date must be bigger, if it does not also point to 0:00:00
+          return !(b->date->startTime.GetHour()==0 &&
+                   b->date->startTime.GetMinute()==0 &&
+                   b->date->startTime.GetSecond()==0);
         }
         else {
           // Both point to full date and time stamps.
-          return date->startTime>tmp->date->startTime;
+          return a->date->startTime<b->date->startTime;
         }
       }
       else {
@@ -105,7 +92,8 @@ namespace Views {
     viewAction(new Lum::Model::Action),
     addAction(new Lum::Model::Action),
     deleteAction(new Lum::Model::Action),
-    model(new Lum::Model::ListTable()),
+    model(new DatesEntryModel(new DatesEntryDataProvider(),
+                              new DatesEntryComparator())),
     table(NULL),top(NULL)
   {
     Observe(viewAction);
@@ -124,7 +112,7 @@ namespace Views {
                                  const Lum::Base::Calendar& endDate)
   {
     if (endDate>=now) {
-      model->Append(new DatesEntry(model,date,startDate,endDate));
+      model->Append(new DatesEntry(date,startDate,endDate));
     }
   }
 
