@@ -1,8 +1,6 @@
 #ifndef VIEWS_NOTES_H
 #define VIEWS_NOTES_H
 
-#include "../GUI.h"
-
 #include <list>
 
 #include <Lum/Model/Table.h>
@@ -10,15 +8,35 @@
 #include <Lum/Panel.h>
 #include <Lum/Table.h>
 
+#include "../GUI.h"
+
+#include "../Data/Note.h"
+
 namespace Views {
 
+  class NotesEntry
+  {
+  public:
+    ::Data::NotePtr note;
+
+  public:
+    NotesEntry(::Data::NotePtr note)
+    : note(note)
+    {
+      // no code
+    }
+  };
+
+  typedef Lum::Model::StdTable<NotesEntry*>     NotesEntryModel;
+  typedef Lum::Base::Reference<NotesEntryModel> NotesEntryModelRef;
+
   class Notes : public ::Base::View
   {
   private:
     Lum::Model::ActionRef    viewAction;
     Lum::Model::ActionRef    addAction;
     Lum::Model::ActionRef    deleteAction;
-    Lum::Model::ListTableRef model;
+    NotesEntryModelRef       model;
     Lum::Table               *table;
     Lum::Panel               *top;
 
