@@ -1,8 +1,6 @@
 #ifndef VIEWS_PEOPLE_H
 #define VIEWS_PEOPLE_H
 
-#include "../GUI.h"
-
 #include <list>
 
 #include <Lum/Model/Table.h>
@@ -10,15 +8,35 @@
 #include <Lum/Panel.h>
 #include <Lum/Table.h>
 
+#include "../GUI.h"
+
+#include "../Data/Person.h"
+
 namespace Views {
 
+  class PeopleEntry
+  {
+  public:
+    ::Data::PersonPtr person;
+
+  public:
+    PeopleEntry(::Data::PersonPtr person)
+    : person(person)
+    {
+      // no code
+    }
+  };
+
+  typedef Lum::Model::StdTable<PeopleEntry*>     PeopleEntryModel;
+  typedef Lum::Base::Reference<PeopleEntryModel> PeopleEntryModelRef;
+
   class People : public ::Base::View
   {
   private:
     Lum::Model::ActionRef    viewAction;
     Lum::Model::ActionRef    addAction;
     Lum::Model::ActionRef    deleteAction;
-    Lum::Model::ListTableRef model;
+    PeopleEntryModelRef      model;
     Lum::Table               *table;
     Lum::Panel               *top;
 
