@@ -16,7 +16,7 @@ namespace Views {
   {
   private:
     Lum::Model::ActionRef       doubleClickAction;
-    Lum::Model::ListTableRef    model;
+    Lum::Model::StringTableRef  model;
     Lum::Table                  *table;
     std::list< ::Base::ViewPtr> views;
 
